# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import uuid
import pydantic
import typing


class CategoryTranscription(UniversalBaseModel):
    id: uuid.UUID = pydantic.Field()
    """
    ID of the transcription
    """

    title: str = pydantic.Field()
    """
    Title of the transcription
    """

    status: str = pydantic.Field()
    """
    Current status of the transcription
    """

    position: typing.Optional[int] = pydantic.Field(default=None)
    """
    Position of this transcription within the category
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
